nx.data.Force - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.data.Force Class

Module: nx.geometry

NeXt force layout algorithm class

- Index
- Methods

## Item Index

### Methods

- setData
- start
- tick

## Methods

### `setData`

(

- `inJson`

)

Set data to this algorithm

#### Parameters:

- `inJson` Object

  Follow Common Topology Data Definition

### `start`

()

Start processing

### `tick`

()

Tick whole force stage